OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veuillez sélectionner un fichier.",
    "File is too big" : "Fichier trop volumineux",
    "Invalid file provided" : "Fichier non valide",
    "No image or file provided" : "Aucun fichier fourni",
    "Unknown filetype" : "Type de fichier inconnu",
    "Invalid image" : "Image non valable",
    "An error occurred. Please contact your admin." : "Une erreur est survenue. Veuillez contacter votre administrateur.",
    "No temporary profile picture available, try again" : "Aucune image temporaire disponible pour le profil. Essayez à nouveau.",
    "No crop data provided" : "Aucune donnée de recadrage fournie",
    "No valid crop data provided" : "Données de recadrage non valides",
    "Crop is not square" : "Le recadrage n'est pas carré",
    "Couldn't reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton n'est pas valable.",
    "Couldn't reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
    "Couldn't send reset email. Please make sure your username is correct." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez vérifier que votre nom d'utilisateur est correct.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation car il n'y a aucune adresse de courriel pour cet utilisateur. Veuillez contacter votre administrateur.",
    "%s password reset" : "Réinitialisation de votre mot de passe %s",
    "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
    "Error loading tags" : "Erreur lors du chargement des étiquettes",
    "Tag already exists" : "L'étiquette existe déjà.",
    "Error deleting tag(s)" : "Erreur de suppression d'étiquette(s)",
    "Error tagging" : "Erreur lors de l'étiquetage",
    "Error untagging" : "Erreur lors du désétiquetage",
    "Error favoriting" : "Erreur lors de la mise en favori",
    "Error unfavoriting" : "Erreur lors de la suppression des favoris",
    "Couldn't send mail to following users: %s " : "Impossible d'envoyer un courriel aux utilisateurs suivants : %s",
    "Preparing update" : "Préparation de la mise à jour",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Avertissement de réparation :",
    "Repair error: " : "Erreur de réparation :",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Veuillez utiliser la mise à jour en lignes de commandes, la mise à jour automatique est désactivée dans config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Vérification de la table %s",
    "Turned on maintenance mode" : "Mode de maintenance activé",
    "Turned off maintenance mode" : "Mode de maintenance désactivé",
    "Maintenance mode is kept active" : "Le mode de maintenance est laissé actif",
    "Updating database schema" : "Mise à jour du schéma de la base de données",
    "Updated database" : "Base de données mise à jour",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données (cela peut prendre un certain temps selon la taille de la base de données)",
    "Checked database schema update" : "Mise à jour du schéma de la base de données vérifiée",
    "Checking updates of apps" : "Recherche de mises à jour d'applications",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
    "Checked database schema update for apps" : "Mise à jour du schéma de la base de données pour les applications vérifiée",
    "Updated \"%s\" to %s" : "Mise à jour de « %s » vers %s",
    "Set log level to debug" : "Réglage du niveau de log à \"debug\"",
    "Reset log level" : "Réinitialisation du niveau de journalisation",
    "Starting code integrity check" : "Lancement de la vérification d'intégrité du code",
    "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
    "%s (3rdparty)" : "%s (origine tierce)",
    "%s (incompatible)" : "%s (non compatible)",
    "Following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
    "Already up to date" : "Déjà à jour",
    "Sunday" : "Dimanche",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Sun." : "Dim.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Jeu.",
    "Fri." : "Ven.",
    "Sat." : "Sam.",
    "Su" : "Di",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Je",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "janvier",
    "February" : "février",
    "March" : "mars",
    "April" : "avril",
    "May" : "mai",
    "June" : "juin",
    "July" : "juillet",
    "August" : "août",
    "September" : "septembre",
    "October" : "octobre",
    "November" : "novembre",
    "December" : "décembre",
    "Jan." : "Jan.",
    "Feb." : "Fév.",
    "Mar." : "Mars",
    "Apr." : "Avr.",
    "May." : "Mai",
    "Jun." : "Juin",
    "Jul." : "Juil.",
    "Aug." : "Août",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Déc.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Il y a eu des problèmes à la vérification d’intégrité du code. Plus d'infos...</a>",
    "Settings" : "Paramètres",
    "Problem loading page, reloading in 5 seconds" : "Problème de chargement de la page , actualisation dans 5 secondes",
    "Saving..." : "Enregistrement…",
    "Dismiss" : "Ignorer",
    "seconds ago" : "à l'instant",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Un lien permettant de réinitialiser votre mot de passe vient de vous être envoyé par courriel.<br>Si vous ne le recevez pas dans un délai raisonnable, contactez votre administrateur.<br>N'oubliez pas de vérifier dans votre dossier pourriel / spam!",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura aucun moyen de récupérer vos données une fois le mot de passe réinitialisé.<br />Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. <br />Voulez-vous vraiment continuer ?",
    "I know what I'm doing" : "Je sais ce que je fais",
    "Password can not be changed. Please contact your administrator." : "Le mot de passe ne peut être modifié. Veuillez contacter votre administrateur.",
    "No" : "Non",
    "Yes" : "Oui",
    "Choose" : "Choisir",
    "Error loading file picker template: {error}" : "Erreur lors du chargement du modèle du sélecteur de fichiers : {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Erreur de chargement du modèle de message : {error}",
    "read-only" : "Lecture seule",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fichier en conflit","{count} fichiers en conflit"],
    "One file conflict" : "Un conflit de fichier",
    "New Files" : "Nouveaux fichiers",
    "Already existing files" : "Fichiers déjà existants",
    "Which files do you want to keep?" : "Quels fichiers désirez-vous garder ?",
    "If you select both versions, the copied file will have a number added to its name." : "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
    "Cancel" : "Annuler",
    "Continue" : "Continuer",
    "(all selected)" : "(tous sélectionnés)",
    "({count} selected)" : "({count} sélectionné(s))",
    "Error loading file exists template" : "Erreur de chargement du modèle de fichier existant",
    "Very weak password" : "Mot de passe très faible",
    "Weak password" : "Mot de passe faible",
    "So-so password" : "Mot de passe tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe fort",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Votre serveur web n'est pas correctement configuré pour la synchronisation de fichiers : l'interface WebDAV semble ne pas fonctionner.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuration du serveur web ne permet pas d'atteindre \"{url}\". Consultez la <a target=\"_blank\" ref=\"noreferrer\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ce serveur ne peut se connecter à internet. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que les notifications par mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Aucun cache de la mémoire n'est configuré. Si possible, configurez un \"memcache\" pour augmenter les performances. Pour plus d'information consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom n'est pas lisible par PHP, ce qui est fortement déconseillé pour des raisons de sécurité. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Vous utilisez actuellement PHP {version}. Nous vous encourageons à mettre à jour votre version de PHP afin de tirer avantage des amélioration liées à <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">la performance et la sécurité fournies par le PHP Group</a>, dès que votre distribution le supportera.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuration des entêtes du proxy inverse est incorrecte, ou vous accédez à ownCloud depuis un proxy de confiance. Si vous n'êtes pas en train d’accéder à ownCloud depuis un proxy de confiance, ceci est un problème de sécurité qui peut permettre à un attaquant de masquer sa véritable adresse IP. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "\"memcached\" est configuré comme cache distribué, mais  le module installé est \"memcache\".  \\OC\\Memcache\\Memcached ne prend en charge que \"memcached\" et non \"memcache\". <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">Consulter le wiki de memcached à propos de ces deux modules.</a>",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Des fichiers n'ont pas réussi à passer la vérification d’intégrité. Plus d'information sur comment résoudre ce problème dans notre <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste des fichiers invalides…</a> / <a href=\"{rescanEndpoint}\">Relancer…</a>)",
    "Error occurred while checking server setup" : "Une erreur s'est produite lors de la vérification de la configuration du serveur",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou de le déplacer hors de la racine du serveur web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'en-tête HTTP \"{header}\" n'est pas configurée pour être égale à \"{expected}\" créant potentiellement un risque relié à la sécurité et à la vie privée. Il est donc recommandé d'ajuster ce paramètre.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "L'en-tête HTTP \"Strict-Transport-Security\" n'est pas configurée à \"{seconds}\" secondes. Pour renforcer la sécurité nous recommandons d'activer HSTS comme décrit dans notre <a href=\"{docUrl} rel=\"noreferrer\">Guide pour le renforcement et la sécurité</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Vous accédez à ce site via HTTP. Nous vous recommandons fortement de configurer votre serveur pour forcer l'utilisation de HTTPS, comme expliqué dans notre <a href=\"{docUrl}\">Guide pour le renforcement et la sécurité</a>.",
    "Shared" : "Partagé",
    "Shared with {recipients}" : "Partagé avec {recipients}",
    "Error" : "Erreur",
    "Error while sharing" : "Erreur lors de la mise en partage",
    "Error while unsharing" : "Erreur lors de l'annulation du partage",
    "Error setting expiration date" : "Erreur lors de la spécification de la date d'expiration",
    "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
    "Set expiration date" : "Spécifier une date d'expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Date d'expiration",
    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
    "Resharing is not allowed" : "Le repartage n'est pas autorisé",
    "Share link" : "Partager par lien public",
    "Link" : "Lien",
    "Password protect" : "Protéger par un mot de passe",
    "Password" : "Mot de passe",
    "Allow editing" : "Permettre la modification",
    "Email link to person" : "Envoyer le lien par courriel",
    "Send" : "Envoyer",
    "Sending ..." : "Envoi…",
    "Email sent" : "Courriel envoyé",
    "Send link via email" : "Envoyer le lien par mail",
    "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
    "Shared with you by {owner}" : "Partagé avec vous par {owner}",
    "group" : "groupe",
    "remote" : "distant",
    "notify by email" : "notifier par courriel",
    "Unshare" : "Ne plus partager",
    "can share" : "peut partager",
    "can edit" : "peut modifier",
    "create" : "création",
    "change" : "modification",
    "delete" : "suppression",
    "access control" : "contrôle d'accès",
    "Could not unshare" : "Impossible d'arrêter de partager",
    "Share details could not be loaded for this item." : "Les informations de partage n'ont pu être chargées pour cet élément.",
    "No users or groups found for {search}" : "Pas d'utilisateur ou de groupe trouvé pour {search}",
    "No users found for {search}" : "Aucun utilisateur trouvé pour {search}",
    "An error occurred. Please try again" : "Une erreur est survenue. Merci de réessayer",
    "{sharee} (group)" : "{sharee} (groupe)",
    "{sharee} (at {server})" : "{sharee} (sur {server})",
    "{sharee} (remote)" : "{sharee} (distant)",
    "Share" : "Partager",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partagez avec des personnes sur d'autres ownClouds en utilisant la syntaxe utilisateur@exemple.com/owncloud",
    "Share with users…" : "Partager avec des utilisateurs...",
    "Share with users, groups or remote users…" : "Partager avec des utilisateurs, groupes ou utilisateurs distants...",
    "Share with users or groups…" : "Partager avec des utilisateurs ou des groupes...",
    "Share with users or remote users…" : "Partager avec des utilisateurs ou des utilisateurs distants...",
    "Error removing share" : "Erreur lors de l'arrêt du partage",
    "Warning" : "Attention",
    "Error while sending notification" : "Erreur lors de l'envoi de la notification",
    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
    "restricted" : "Restreint",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Supprimer",
    "Rename" : "Renommer",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "The object type is not specified." : "Le type d'objet n'est pas spécifié.",
    "Enter new" : "Saisir un nouveau",
    "Add" : "Ajouter",
    "Edit tags" : "Modifier les étiquettes",
    "Error loading dialog template: {error}" : "Erreur lors du chargement du modèle de dialogue : {error}",
    "No tags selected for deletion." : "Aucune étiquette sélectionnée pour la suppression.",
    "unknown text" : "texte inconnu",
    "Hello world!" : "Hello world!",
    "sunny" : "ensoleillé",
    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
    "Hello {name}" : "Hello {name}",
    "new" : "Nouveau ",
    "_download %n file_::_download %n files_" : ["Télécharger %n fichier","Télécharger %n fichiers"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours. Selon la configuration, le fait de quitter cette page peut entraîner l'interruption de la procédure.",
    "Updating to {version}" : "En cours de mise à jour vers la version {version}",
    "An error occurred." : "Une erreur est survenue.",
    "Please reload the page." : "Veuillez recharger la page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d'informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La mise à jour a échoué. Veuillez signaler ce problème à la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">communauté ownCloud</a>.",
    "The update was successful. There were warnings." : "La mise à jour a réussi, mais il y a eu des avertissements",
    "The update was successful. Redirecting you to ownCloud now." : "La mise à jour a réussi. Vous êtes maintenant redirigé vers ownCloud.",
    "Searching other places" : "Recherche en cours dans d'autres emplacements",
    "No search results in other folders" : "Aucun résultat dans d'autres dossiers",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} résultat dans un autre dossier","{count} résultats dans d'autres dossiers"],
    "Personal" : "Personnel",
    "Users" : "Utilisateurs",
    "Apps" : "Applications",
    "Admin" : "Administration",
    "Help" : "Aide",
    "Access forbidden" : "Accès interdit",
    "File not found" : "Fichier non trouvé",
    "The specified document has not been found on the server." : "Impossible de trouver le document spécifié sur le serveur.",
    "You can click here to return to %s." : "Vous pouvez cliquer ici pour retourner à %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Bonjour,\n\nNous vous informons que %s a partagé \"%s\" avec vous.\nVous pouvez y accéder à l'adresse suivante : %s\n",
    "The share will expire on %s." : "Le partage expirera le %s.",
    "Cheers!" : "À bientôt !",
    "Internal Server Error" : "Erreur interne du serveur",
    "The server encountered an internal error and was unable to complete your request." : "Le serveur a rencontré une erreur interne et est incapable d'exécuter votre requête.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Veuillez contacter l'administrateur du serveur si cette erreur apparaît plusieurs fois. Veuillez joindre les détails techniques à votre rapport.",
    "More details can be found in the server log." : "Le fichier journal du serveur peut fournir plus de renseignements.",
    "Technical details" : "Renseignements techniques",
    "Remote Address: %s" : "Adresse distante : %s",
    "Request ID: %s" : "ID de la demande : %s",
    "Type: %s" : "Type : %s",
    "Code: %s" : "Code : %s",
    "Message: %s" : "Message : %s",
    "File: %s" : "Fichier : %s",
    "Line: %s" : "Ligne : %s",
    "Trace" : "Trace",
    "Security warning" : "Avertissement de sécurité",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis l'internet car le fichier .htaccess ne fonctionne pas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "Créer un <strong>compte administrateur</strong>",
    "Username" : "Nom d'utilisateur",
    "Storage & database" : "Stockage & base de données",
    "Data folder" : "Répertoire des données",
    "Configure the database" : "Configurer la base de données",
    "Only %s is available." : "Seul(e) %s est disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d'autres types de base de données.",
    "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
    "Database user" : "Utilisateur de la base de données",
    "Database password" : "Mot de passe de la base de données",
    "Database name" : "Nom de la base de données",
    "Database tablespace" : "Tablespace de la base de données",
    "Database host" : "Hôte de la base de données",
    "Performance warning" : "Avertissement à propos des performances",
    "SQLite will be used as database." : "SQLite sera utilisé comme gestionnaire de base de données.",
    "For larger installations we recommend to choose a different database backend." : "Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "En particulier si vous utilisez le client de bureau pour synchroniser vos données : l'utilisation de SQLite est alors déconseillée.",
    "Finish setup" : "Terminer l'installation",
    "Finishing …" : "Finalisation …",
    "Need help?" : "Besoin d'aide ?",
    "See the documentation" : "Lire la documentation",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjour,<br><br>Nous vous informons que %s a partagé <strong>%s</strong> avec vous.<br><a href=\"%s\">Cliquez ici pour y accéder !</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
    "Log out" : "Se déconnecter",
    "Search" : "Rechercher",
    "Server side authentication failed!" : "L'authentification sur le serveur a échoué !",
    "Please contact your administrator." : "Veuillez contacter votre administrateur.",
    "An internal error occurred." : "Une erreur interne est survenue.",
    "Please try again or contact your administrator." : "Veuillez réessayer ou contacter votre administrateur.",
    "Username or email" : "Nom d'utilisateur ou e-mail",
    "Log in" : "Se connecter",
    "Wrong password. Reset it?" : "Mot de passe incorrect. Réinitialiser ?",
    "Wrong password." : "Mot de passe incorrect.",
    "Stay logged in" : "Rester connecté",
    "Alternative Logins" : "Identifiants alternatifs",
    "Use the following link to reset your password: {link}" : "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
    "New password" : "Nouveau mot de passe",
    "New Password" : "Nouveau mot de passe",
    "Reset password" : "Réinitialiser le mot de passe",
    "This ownCloud instance is currently in single user mode." : "Cette instance de ownCloud est actuellement en mode utilisateur unique.",
    "This means only administrators can use the instance." : "Cela signifie que seuls les administrateurs peuvent utiliser l'instance.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
    "Thank you for your patience." : "Merci de votre patience.",
    "Two-step verification" : "Vérification en deux étapes",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "La sécurité renforcée a été activée pour votre compte. Veuillez vous identifier en utilisant un deuxième facteur.",
    "Cancel login" : "Annuler la connexion",
    "Please authenticate using the selected factor." : "Veuillez vous identifier en utilisant le facteur sélectionné.",
    "An error occured while verifying the token" : "Une erreur est survenue lors de la vérification du jeton",
    "You are accessing the server from an untrusted domain." : "Vous accédez au serveur à partir d'un domaine non approuvé.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Veuillez contacter votre administrateur. Si vous être l'administrateur de cette instance, configurez la variable \"trusted_domains\" dans le fichier config/config.php. Un exemple de configuration est fournit dans le fichier config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En fonction de votre configuration, en tant qu'administrateur vous pouvez également utiliser le bouton ci-dessous pour approuver ce domaine.",
    "Add \"%s\" as trusted domain" : "Ajouter \"%s\" à la liste des domaines approuvés",
    "App update required" : "Mise à jour de l'application nécessaire",
    "%s will be updated to version %s" : "%s sera mis à jour vers la version %s.",
    "These apps will be updated:" : "Les applications suivantes seront mises à jour:",
    "These incompatible apps will be disabled:" : "Ces applications incompatibles ont été désactivées:",
    "The theme %s has been disabled." : "Le thème %s a été désactivé.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu'une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
    "Start update" : "Démarrer la mise à jour",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les timeouts avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
    "Detailed logs" : "Journaux détaillés",
    "Update needed" : "Mise à jour nécessaire",
    "Please use the command line updater because you have a big instance." : "Veuillez utiliser la mise à jour en lignes de commandes, votre instance est trop volumineuse.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
    "This page will refresh itself when the %s instance is available again." : "Cette page se rafraîchira d'elle-même lorsque l'instance %s sera à nouveau disponible."
},
"nplurals=2; plural=(n > 1);");
